@@ -35,10 +35,10 @@
 static char sccsid[] = "@(#)commands.c	8.2 (Berkeley) 12/15/93";
 #endif /* not lint */
 
-/* 	$Id: commands.c,v 1.5 1995/11/23 15:42:30 martin Exp martin $	 */
+/* 	$Id: commands.c,v 1.9 1997/08/22 10:09:45 martin Exp $	 */
 
 #ifndef lint
-static char vcid[] = "$Id: commands.c,v 1.5 1995/11/23 15:42:30 martin Exp martin $";
+static char vcid[] = "$Id: commands.c,v 1.9 1997/08/22 10:09:45 martin Exp $";
 #endif /* lint */
 
 #include "../config.h"
@@ -58,11 +58,7 @@ static char vcid[] = "$Id: commands.c,v 1.5 1995/11/23 15:42:30 martin Exp marti
 #if HAVE_SYS_WAIT_H
 # include <sys/wait.h>
 #endif
-#if defined(__ultrix)
-# include <cxx/sys/socket.h>
-#else
-# include <sys/socket.h>
-#endif
+#include <sys/socket.h>
 #include <netinet/in.h>
 #ifdef	CRAY
 #include <fcntl.h>
@@ -115,7 +111,7 @@ extern int display_connect_details();
 
 #ifndef       MAXHOSTNAMELEN
 #define       MAXHOSTNAMELEN 64
-#endif        MAXHOSTNAMELEN
+#endif        /* MAXHOSTNAMELEN */
 
 #if	defined(IPPROTO_IP) && defined(IP_TOS)
 int tos = -1;
@@ -1177,7 +1173,7 @@ dolmmode(bit, on)
 }
 
     int
-setmode(bit)
+xsetmode(bit)
     int bit;
 {
     return dolmmode(bit, 1);
@@ -1211,17 +1207,17 @@ static struct modelist ModeList[] = {
 #endif
     { "", "", 0 },
     { "",	"These require the LINEMODE option to be enabled", 0 },
-    { "isig",	"Enable signal trapping",	setmode, 1, MODE_TRAPSIG },
-    { "+isig",	0,				setmode, 1, MODE_TRAPSIG },
+    { "isig",	"Enable signal trapping",	xsetmode, 1, MODE_TRAPSIG },
+    { "+isig",	0,				xsetmode, 1, MODE_TRAPSIG },
     { "-isig",	"Disable signal trapping",	clearmode, 1, MODE_TRAPSIG },
-    { "edit",	"Enable character editing",	setmode, 1, MODE_EDIT },
-    { "+edit",	0,				setmode, 1, MODE_EDIT },
+    { "edit",	"Enable character editing",	xsetmode, 1, MODE_EDIT },
+    { "+edit",	0,				xsetmode, 1, MODE_EDIT },
     { "-edit",	"Disable character editing",	clearmode, 1, MODE_EDIT },
-    { "softtabs", "Enable tab expansion",	setmode, 1, MODE_SOFT_TAB },
-    { "+softtabs", 0,				setmode, 1, MODE_SOFT_TAB },
+    { "softtabs", "Enable tab expansion",	xsetmode, 1, MODE_SOFT_TAB },
+    { "+softtabs", 0,				xsetmode, 1, MODE_SOFT_TAB },
     { "-softtabs", "Disable character editing",	clearmode, 1, MODE_SOFT_TAB },
-    { "litecho", "Enable literal character echo", setmode, 1, MODE_LIT_ECHO },
-    { "+litecho", 0,				setmode, 1, MODE_LIT_ECHO },
+    { "litecho", "Enable literal character echo", xsetmode, 1, MODE_LIT_ECHO },
+    { "+litecho", 0,				xsetmode, 1, MODE_LIT_ECHO },
     { "-litecho", "Disable literal character echo", clearmode, 1, MODE_LIT_ECHO },
     { "help",	0,				modehelp, 0 },
 #ifdef	KLUDGELINEMODE
@@ -1443,7 +1439,9 @@ shell(argc, argv)
 	     * Fire up the shell in the child.
 	     */
 	    register char *shellp, *shellname;
+#ifndef rindex
 	    extern char *rindex();
+#endif
 
 	    shellp = getenv("SHELL");
 	    if (shellp == NULL)
@@ -1733,7 +1731,9 @@ env_init()
 	extern char **environ;
 	register char **epp, *cp;
 	register struct env_lst *ep;
+#ifndef index
 	extern char *index();
+#endif
 
 	for (epp = environ; *epp; epp++) {
 		if ((cp = index(*epp, '='))) {
@@ -2280,7 +2280,7 @@ tn(argc, argv)
     unsigned long temp;
     extern char *inet_ntoa();
 #if	defined(IP_OPTIONS) && defined(IPPROTO_IP)
-    char *srp = 0, *strrchr();
+    char *srp = 0;
     unsigned long sourceroute(), srlen;
 #endif
     char *cmd, *hostp = 0, *portp = 0, *user = 0;
@@ -2502,7 +2502,7 @@ tn(argc, argv)
 	 */
 	SSL_load_error_strings();
 
-	ssl_ctx=(SSL *)SSL_CTX_new();
+	ssl_ctx=(SSL_CTX *)SSL_CTX_new();
 	ssl_con=(SSL *)SSL_new(ssl_ctx);
 
         SSL_set_fd(ssl_con,net);
@@ -2517,7 +2517,7 @@ tn(argc, argv)
 	    if (!SSL_use_certificate_file(ssl_con, cert_file,
 		X509_FILETYPE_PEM)) {
 		fprintf(stderr,"%s: ",cert_file);
-		ERR_print_errors(stderr);
+		ERR_print_errors_fp(stderr);
 		exit(1);
 	    } else {
 		if (!key_file)
@@ -2525,7 +2525,7 @@ tn(argc, argv)
 		if (!SSL_use_RSAPrivateKey_file(ssl_con, key_file,
 		    X509_FILETYPE_PEM)) {
 		    fprintf(stderr,"%s: ", key_file);
-		    ERR_print_errors(stderr);
+		    ERR_print_errors_fp(stderr);
 		    exit(1);
 		}
 	    }
@@ -2535,7 +2535,7 @@ tn(argc, argv)
 	    if (!SSL_connect(ssl_con)) {
                 static char errbuf[1024];
 
-		ERR_print_errors(stderr);
+		ERR_print_errors_fp(stderr);
 		perror("SSL_connect");
 		fflush(stderr);
 
