@@ -35,10 +35,10 @@
 static char sccsid[] = "@(#)sys_term.c	8.2 (Berkeley) 12/15/93";
 #endif /* not lint */
 
-/* 	$Id: sys_term.c,v 1.9 1996/06/13 14:19:08 martin Exp $	 */
+/* 	$Id: sys_term.c,v 1.10 1997/08/22 10:18:33 martin Exp $	 */
 
 #ifndef lint
-static char vcid[] = "$Id: sys_term.c,v 1.9 1996/06/13 14:19:08 martin Exp $";
+static char vcid[] = "$Id: sys_term.c,v 1.10 1997/08/22 10:18:33 martin Exp $";
 #endif /* lint */
 
 #include "telnetd.h"
@@ -57,7 +57,7 @@ static char vcid[] = "$Id: sys_term.c,v 1.9 1996/06/13 14:19:08 martin Exp $";
 #include <initreq.h>
 int	utmp_len = MAXHOSTNAMELEN;	/* sizeof(init_request.host) */
 #else	/* NEWINIT*/
-# ifdef HAVE_UTMPX_H
+# if defined(HAVE_UTMPX_H) && !defined(hpux)
 #  define UTMPX
 # include <utmpx.h>
 struct	utmpx wtmp;
@@ -69,6 +69,10 @@ struct	utmp wtmp;
 #ifdef HAVE_UT_HOST
 int	utmp_len = sizeof(wtmp.ut_host);
 #endif
+#ifdef __linux
+char    wtmpf[] = "/var/log/wtmp";
+char    utmpf[] = "/var/run/utmp";
+#else
 # ifndef PARENT_DOES_UTMP
 char	wtmpf[]	= "/usr/adm/wtmp";
 char	utmpf[] = "/etc/utmp";
@@ -76,6 +80,7 @@ char	utmpf[] = "/etc/utmp";
 char	wtmpf[]	= "/etc/wtmp";
 char    utmpf[] = "/etc/utmp";
 # endif /* PARENT_DOES_UTMP */
+#endif
 
 # ifdef CRAY
 #include <tmpdir.h>
@@ -624,7 +629,7 @@ int *ptynum;
 	/*	int t;*/
 	char *ptsname();
 
-	p = open("/dev/ptmx", 2);
+	p = open("/dev/ptmx", O_RDWR);
 	if (p > 0) {
 		grantpt(p);
 		unlockpt(p);
@@ -660,6 +665,17 @@ int *ptynum;
 	    strcpy (line, tty_name);
 	    return 0;
 	}
+#endif
+#if defined(hpux)
+	{
+	  char *ptsname();
+
+	  p = open("/dev/ptym/clone", O_RDWR);
+	  if (p > 0) {
+	    strcpy(line, ptsname(p));
+            return(p);
+	  }
+	}
 #endif
 	pty_search(&p);
 
@@ -1169,7 +1185,7 @@ tty_isnewmap()
 
 #ifdef PARENT_DOES_UTMP
 # ifndef NEWINIT
-extern	struct utmp wtmp;
+/*extern	struct utmp wtmp;*/
 extern char wtmpf[];
 # else	/* NEWINIT */
 int	gotalarm;
@@ -1263,8 +1279,10 @@ getptyslave()
 	if (ioctl(t, I_PUSH, "ldterm") < 0)
 		fatal(net, "I_PUSH ldterm");
 #ifndef sgi
+#ifndef hpux
 	if (ioctl(t, I_PUSH, "ttcompat") < 0)
 		fatal(net, "I_PUSH ttcompat");
+#endif
 	if (ioctl(pty, I_PUSH, "pckt") < 0)
 		fatal(net, "I_PUSH pckt");
 #endif
@@ -1384,6 +1402,7 @@ cleanopen(line)
 	}
 #endif	/* _SC_CRAY_SECURE_SYS */
 
+	logprintf("cleanopen: %s\n",line);
 	t = open(line, O_RDWR|O_NOCTTY);
 
 #if	defined(_SC_CRAY_SECURE_SYS)
@@ -1715,6 +1734,7 @@ start_login(host, autologin, name)
 	char termbuf[64];
 #endif
 
+	logprintf("start_login %d\n",autologin);
 #ifdef	UTMPX
 	/*
 	 * Create utmp entry for child
@@ -1905,6 +1925,7 @@ start_login(host, autologin, name)
 		close(pty);
 #endif
 	closelog();
+	logprintf("start_login: vor exec\n");
 	execv(_PATH_LOGIN, argv);
 
 	syslog(LOG_ERR, "%s: %m\n", _PATH_LOGIN);
@@ -2260,8 +2281,8 @@ rmut()
 		utxp->ut_type = DEAD_PROCESS;
 		utxp->ut_exit.e_termination = 0;
 		utxp->ut_exit.e_exit = 0;
-		(void) time(&utmpx.ut_tv.tv_sec);
-		utmpx.ut_tv.tv_usec = 0;
+		(void) time(&utxp->ut_tv.tv_sec);
+		utxp->ut_tv.tv_usec = 0;
 		modutx(utxp);
 	}
 	endutxent();
