@@ -35,10 +35,10 @@
 static char sccsid[] = "@(#)utility.c	8.2 (Berkeley) 12/15/93";
 #endif /* not lint */
 
-/* 	$Id: utility.c,v 1.3 1995/11/15 10:16:43 martin Exp $	 */
+/* 	$Id: utility.c,v 1.5 1997/08/22 10:21:59 martin Exp $	 */
 
 #ifndef lint
-static char vcid[] = "$Id: utility.c,v 1.3 1995/11/15 10:16:43 martin Exp $";
+static char vcid[] = "$Id: utility.c,v 1.5 1997/08/22 10:21:59 martin Exp $";
 #endif /* lint */
 
 #define PRINTOPTIONS
@@ -386,7 +386,7 @@ logprintf(char *format, ...)
 	    fprintf(fd, "%s",ctime(&t));
 	    first = 0;
 	}
-    fprintf(fd, "telnetd(%d):", getpid());
+    fprintf(fd, "telnetd(%d,%d):", getpid(), fileno(fd));
     va_start(args, format);
     vfprintf(fd, format, args);
     fflush(fd);
@@ -443,7 +443,6 @@ edithost(pat, host)
 	register char *host;
 {
 	register char *res = editedhost;
-	char *strncpy();
 
 	if (!pat)
 		pat = "";
@@ -512,9 +511,13 @@ putf(cp, where)
 	time_t t;
 	char db[100];
 #ifdef	STREAMSPTY
+#ifndef index
 	extern char *index();
+#endif
 #else
+#ifndef rindex
 	extern char *rindex();
+#endif
 #endif
 
 	putlocation = where;
